==> speech-analytic-testing_3.5.5_database.tar.gz: database/mssql/procedures/BulkInteractionCognitive.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[BulkInteractionCognitive]
AS
BEGIN
	SET NOCOUNT ON
	
	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS PLANES Y SU CORRESPONDIENTE VCC
	DECLARE MY_CURSOR CURSOR 
	LOCAL STATIC READ_ONLY FORWARD_ONLY -- SCROLL 
		FOR 
		-- CONSULTAMOS LOS ID DE PLANES EN LA TABLA TEMPORAL
		SELECT DISTINCT
				[VCC],
				[StudyId]		
			FROM [dbo].[#InteractionCognitiveTemp]  (NOLOCK)

	-- DECLARARAMOS VARIABLES PARA INDICAR EL PLAN Y VCC
	DECLARE @CURRENT_VCC VARCHAR(50) = ''
	DECLARE @CURRENT_STUDY_ID VARCHAR(100) = ''

	-- ABRIMOS Y RECORREMOS EL ARRAY DE CANALES
	OPEN MY_CURSOR
	FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_STUDY_ID
	WHILE @@FETCH_STATUS = 0
	BEGIN 
		-- EJECUTAMOS EL SP QUE INSERTA LOS RESULT BASE DE LOS ESTUDIOS QUE AUN NO LOS TIENEN
		EXEC [dbo].[SaveStudyBaseResult] @CURRENT_VCC, @CURRENT_STUDY_ID
		
		FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_STUDY_ID
	END
	CLOSE MY_CURSOR
	DEALLOCATE MY_CURSOR
	-- FIN MEDIDA PARA ESTUDIOS FINALIZADOS QUE NO TIENE RESULTS REGISTRADOS



	UPDATE SRSD 
	SET 
          SRSD.[IsMatched] = 1
	    FROM 
	 [StudyResultSummaryDetail] SRSD 
	 JOIN  (
			SELECT DISTINCT
					 [VCC]
					, [StudyId]
					, [TemplateThemeId]
					,[TemplateThemeItemId]
					, [TranscriptionId]
				FROM #InteractionCognitiveTemp
				--WHERE [Channel] = 'CALL'
		) ICT
		    ON (ICT.[VCC] = SRSD.[VCC]
			AND ICT.[StudyId] = SRSD.[StudyId]
			AND ICT.[TemplateThemeId] = SRSD.[TemplateThemeId]
			AND ICT.[TranscriptionId] = SRSD.[TranscriptionId]
			AND ICT.[TemplateThemeItemId] = SRSD.[TemplateThemeItemId]
			)
			
		 WHERE   ICT.[TemplateThemeId] IS NOT NULL 
		


	UPDATE SD 
	SET 
          SD.[IsMatched] = 1
	    FROM 
	 [StudyDetail] SD 
	 JOIN  (
			       SELECT DISTINCT
					 [VCC]
					, [StudyId]
					, [TemplateThemeId]
					,[TemplateThemeItemId]
					, [TranscriptionId]
				FROM #InteractionCognitiveTemp
				--WHERE [Channel] = 'CALL'
		) ICT
		    ON (ICT.[VCC] = SD.[VCC]
			AND ICT.[StudyId] = SD.[StudyId]
			AND ICT.[TemplateThemeId] = SD.[TemplateThemeId]
			AND ICT.[TranscriptionId] = SD.[TranscriptionId]
			AND ICT.[TemplateThemeItemId] = SD.[TemplateThemeItemId]
			)
			
		 WHERE   ICT.[TemplateThemeId] IS NOT NULL 



UPDATE SRS SET SRS.[IsMatched] = 1

FROM [dbo].[StudyResultSummary]  SRS 

JOIN  (SELECT DISTINCT
			 [VCC]
			, [StudyId]
			, [TemplateId]
			, [TemplateThemeId]

		FROM #InteractionCognitiveTemp
		--WHERE [Channel] = 'CALL'
	) ICT   ON (ICT.[VCC] = SRS.[VCC]
			AND ICT.[StudyId] = SRS.[StudyId]
			AND ICT.[TemplateId] = SRS.[TemplateId]
			AND ICT.[TemplateThemeId] = SRS.[TemplateThemeId])

	
	WHERE  ICT.[TemplateThemeId] IS NOT NULL
	

	
	-- ACTUALIZAMOS LA DATA DE ASYNCINTERACTION
	UPDATE [StudyResultSummary]
		SET [Total] = A.TOTAL
		FROM (
			SELECT A.[VCC]
					,A.[StudyId]
					,A.[TemplateId]
					,A.[TemplateThemeId]
					, COUNT(1) TOTAL
				FROM [StudyResultSummaryDetail] SRSD (NOLOCK)
				INNER JOIN (
					SELECT DISTINCT
							[VCC]
							,[StudyId]
							,[TemplateId]
							,[TemplateThemeId]
							,[TemplateThemeItemId]
						FROM #InteractionCognitiveTemp (NOLOCK)
				) A 
					ON SRSD.VCC = A.[VCC] 
						AND SRSD.StudyId = A.StudyId 
						AND SRSD.[TemplateThemeItemId] = A.[TemplateThemeItemId] 
			  JOIN [dbo].[TemplateTheme] TT (NOLOCK) 
			       ON TT.VCC = SRSD.VCC 
			          AND TT.[TemplateId] = A.[TemplateId]
			          AND TT.[ID] = SRSD.[TemplateThemeId]
			   --Si es negativo contarÃ¡ los que quedaron en 0 y los 1 si es positivo
			   WHERE SRSD.[IsMatched] = IIF(TT.[IsNegative] = 1, 0, 1)
				GROUP BY A.[VCC]
						,A.[StudyId]
						,A.[TemplateId]
						,A.[TemplateThemeId]
		) A
		WHERE StudyResultSummary.vcc = a.VCC
			AND StudyResultSummary.StudyId = A.StudyId 
			AND StudyResultSummary.[TemplateThemeId] = A.[TemplateThemeId]
	
	DROP TABLE #InteractionCognitiveTemp

	SELECT 1 'result'

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/BulkInteractionCognitive.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[BulkInteractionCognitive]
AS
BEGIN
	SET NOCOUNT ON
	
	/* 
	SELECT *
		INTO [dbo].[TMP_BULK_MODEL]
		FROM [dbo].[#InteractionCognitiveTemp]
	*/

	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS PLANES Y SU CORRESPONDIENTE VCC
	DECLARE MY_CURSOR CURSOR 
	LOCAL STATIC READ_ONLY FORWARD_ONLY -- SCROLL 
		FOR 
		-- CONSULTAMOS LOS ID DE PLANES EN LA TABLA TEMPORAL
		SELECT DISTINCT
				[VCC],
				[StudyId]		
			FROM [dbo].[#InteractionCognitiveTemp]  (NOLOCK)

	-- DECLARARAMOS VARIABLES PARA INDICAR EL PLAN Y VCC
	DECLARE @CURRENT_VCC VARCHAR(50) = ''
	DECLARE @CURRENT_STUDY_ID VARCHAR(100) = ''

	-- ABRIMOS Y RECORREMOS EL ARRAY DE CANALES
	OPEN MY_CURSOR
	FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_STUDY_ID
	WHILE @@FETCH_STATUS = 0
	BEGIN 
		-- EJECUTAMOS EL SP QUE INSERTA LOS RESULT BASE DE LOS ESTUDIOS QUE AUN NO LOS TIENEN
		EXEC [dbo].[SaveStudyBaseResult] @CURRENT_VCC, @CURRENT_STUDY_ID
		
		FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_STUDY_ID
	END
	CLOSE MY_CURSOR
	DEALLOCATE MY_CURSOR
	-- FIN MEDIDA PARA ESTUDIOS FINALIZADOS QUE NO TIENE RESULTS REGISTRADOS



	UPDATE SRSD 
	SET 
          SRSD.[IsMatched] = 1
	    FROM 
	 [StudyResultSummaryDetail] SRSD 
	 JOIN  (
			SELECT DISTINCT
					 [VCC]
					, [StudyId]
					, [TemplateThemeId]
					,[TemplateThemeItemId]
					, [TranscriptionId]
				FROM #InteractionCognitiveTemp
				--WHERE [Channel] = 'CALL'
		) ICT
		    ON (ICT.[VCC] = SRSD.[VCC]
			AND ICT.[StudyId] = SRSD.[StudyId]
			AND ICT.[TemplateThemeId] = SRSD.[TemplateThemeId]
			AND ICT.[TranscriptionId] = SRSD.[TranscriptionId]
			AND ICT.[TemplateThemeItemId] = SRSD.[TemplateThemeItemId]
			)
			
		 WHERE   ICT.[TemplateThemeId] IS NOT NULL 
		


	UPDATE SD 
	SET 
          SD.[IsMatched] = 1
	    FROM 
	 [StudyDetail] SD 
	 JOIN  (
			       SELECT DISTINCT
					 [VCC]
					, [StudyId]
					, [TemplateThemeId]
					,[TemplateThemeItemId]
					, [TranscriptionId]
				FROM #InteractionCognitiveTemp
				--WHERE [Channel] = 'CALL'
		) ICT
		    ON (ICT.[VCC] = SD.[VCC]
			AND ICT.[StudyId] = SD.[StudyId]
			AND ICT.[TemplateThemeId] = SD.[TemplateThemeId]
			AND ICT.[TranscriptionId] = SD.[TranscriptionId]
			AND ICT.[TemplateThemeItemId] = SD.[TemplateThemeItemId]
			)
			
		 WHERE   ICT.[TemplateThemeId] IS NOT NULL 



UPDATE SRS SET SRS.[IsMatched] = 1

FROM [dbo].[StudyResultSummary]  SRS 

JOIN  (SELECT DISTINCT
			 [VCC]
			, [StudyId]
			, [TemplateId]
			, [TemplateThemeId]

		FROM #InteractionCognitiveTemp
		--WHERE [Channel] = 'CALL'
	) ICT   ON (ICT.[VCC] = SRS.[VCC]
			AND ICT.[StudyId] = SRS.[StudyId]
			AND ICT.[TemplateId] = SRS.[TemplateId]
			AND ICT.[TemplateThemeId] = SRS.[TemplateThemeId])

	
	WHERE  ICT.[TemplateThemeId] IS NOT NULL
	

	
	-- ACTUALIZAMOS LA DATA DE ASYNCINTERACTION
	UPDATE [StudyResultSummary]
		SET [Total] = A.TOTAL
		FROM (
			SELECT A.[VCC]
					,A.[StudyId]
					,A.[TemplateId]
					,A.[TemplateThemeId]
					, COUNT(1) TOTAL
				FROM [StudyResultSummaryDetail] SRSD (NOLOCK)
				INNER JOIN (
					SELECT DISTINCT
							[VCC]
							,[StudyId]
							,[TemplateId]
							,[TemplateThemeId]
							,[TemplateThemeItemId]
						FROM #InteractionCognitiveTemp (NOLOCK)
				) A 
					ON SRSD.VCC = A.[VCC] 
						AND SRSD.StudyId = A.StudyId 
						AND SRSD.[TemplateThemeItemId] = A.[TemplateThemeItemId] 
			  JOIN [dbo].[TemplateTheme] TT (NOLOCK) 
			       ON TT.VCC = SRSD.VCC 
			          AND TT.[TemplateId] = A.[TemplateId]
			          AND TT.[ID] = SRSD.[TemplateThemeId]
			   --Si es negativo contara los que quedaron en 0 y los 1 si es positivo
			   WHERE SRSD.[IsMatched] = IIF(TT.[IsNegative] = 1, 0, 1)
				GROUP BY A.[VCC]
						,A.[StudyId]
						,A.[TemplateId]
						,A.[TemplateThemeId]
		) A
		WHERE StudyResultSummary.vcc = a.VCC
			AND StudyResultSummary.StudyId = A.StudyId 
			AND StudyResultSummary.[TemplateThemeId] = A.[TemplateThemeId]
	
	DROP TABLE #InteractionCognitiveTemp

	SELECT 1 'result'

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
